Enum abstract_client::AccountSource
source · pub enum AccountSource {
Namespace(Namespace),
AccountId(AccountId),
App(Addr),
}Expand description
Represents the a route to fetch an account from.
Variants
Namespace(Namespace)
Get the account from a registered Namespace.
AccountId(AccountId)
Get the account from an AccountId.
App(Addr)
Get the account from the address of an installed App.